@@ -14,9 +14,9 @@
 
 import datetime
 
-from oslo.config import cfg
-from oslo.db.sqlalchemy import session as db_session
-from oslo.db.sqlalchemy import utils as db_utils
+from oslo_config import cfg
+from oslo_db.sqlalchemy import session as db_session
+from oslo_db.sqlalchemy import utils as db_utils
 
 from subunit2sql.db import models
 from subunit2sql import exceptions
@@ -86,7 +86,7 @@ def update_test(values, test_id, session=None):
     """Update an individual test with new data.
 
     This method will take a dictionary of fields to update for a specific test.
-    If a field is ommited it will not be changed in the DB.
+    If a field is omitted it will not be changed in the DB.
 
     :param dict values: dict of values to update the test with. The key is the
                         column name and the value is the new value to be stored
@@ -110,7 +110,7 @@ def create_run(skips=0, fails=0, passes=0, run_time=0, artifacts=None,
                id=None, session=None):
     """Create a new run record in the database
 
-    :param int skips: total number of skiped tests defaults to 0
+    :param int skips: total number of skipped tests defaults to 0
     :param int fails: total number of failed tests defaults to 0
     :param int passes: total number of passed tests defaults to 0
     :param float run_time: total run timed defaults to 0
@@ -214,6 +214,39 @@ def add_run_metadata(meta_dict, run_id, session=None):
     return metadata
 
 
+def get_run_metadata(run_id, session=None):
+    """Return all run metadata objects associated with a given run.
+
+    :param str run_id: The uuid of the run to get all the metadata
+    :param session: optional session object if one isn't provided a new session
+                    will be acquired for the duration of this operation
+
+    :return list: The list of metadata objects
+    :rtype: subunit2sql.models.RunMetadata
+    """
+    session = session or get_session()
+    query = db_utils.model_query(models.RunMetadata, session).filter_by(
+        run_id=run_id)
+    return query.all()
+
+
+def get_runs_by_key_value(key, value, session=None):
+    """Return all run objects associated with a certain key/value metadata pair
+
+    :param key: The key to be matched
+    :param value: The value to be matched
+    :param session: optional session object if one isn't provided a new session
+                    will be acquired for the duration of this operation
+    :return list: The list of runs
+    :rtype: subunit2sql.models.Run
+    """
+    session = session or get_session()
+    query = db_utils.model_query(models.Run, session=session).join(
+        models.RunMetadata).filter_by(key=key, value=value)
+
+    return query.all()
+
+
 def create_test_run(test_id, run_id, status, start_time=None,
                     end_time=None, session=None):
     """Create a new test run record in the database
@@ -473,7 +506,7 @@ def get_test_runs_by_run_id(run_id, session=None):
 
 
 def get_test_run_duration(test_run_id, session=None):
-    """Get the run duration for a specifc test_run.
+    """Get the run duration for a specific test_run.
 
     :param str test_run_id: The test_run's uuid (the id column in the test_run
                             table) to get the duration of
@@ -586,6 +619,45 @@ def get_test_run_time_series(test_id, session=None):
     return time_series
 
 
+def get_test_run_series(start_date=None, stop_date=None, session=None):
+    """Returns a time series dict of total daily run counts
+
+    :param str start_date: Optional start date to filter results on
+    :param str stop_date: Optional stop date to filter results on
+    :param session: optional session object if one isn't provided a new session
+
+    :return dict: A dictionary with the dates as the keys and the values
+                  being the total run count for that day. (The sum of success
+                  and failures from all runs that started that day)
+    """
+    session = session or get_session()
+    full_query = db_utils.model_query(models.Run, session=session).join(
+        models.RunMetadata).filter_by(key='build_queue', value='gate')
+
+    # Process date bounds
+    if isinstance(start_date, str):
+        start_date = datetime.datetime.strptime(start_date, '%b %d %Y')
+    if isinstance(stop_date, str):
+        stop_date = datetime.datetime.strptime(stop_date, '%b %d %Y')
+    if start_date:
+        full_query.filter(models.Run.run_at < start_date)
+    if stop_date:
+        full_query.filter(models.Run.run_at > stop_date)
+
+    query = full_query.values(models.Run.run_at, models.Run.passes,
+                              models.Run.fails)
+    time_series = {}
+    for test_run in query:
+        start_time = test_run[0]
+        # Sum of starts and failures is the count for the run
+        local_run_count = test_run[1] + test_run[2]
+        if start_time in time_series:
+            time_series[start_time] = time_series[start_time] + local_run_count
+        else:
+            time_series[start_time] = local_run_count
+    return time_series
+
+
 def get_test_status_time_series(test_id, session=None):
     """Returns a time series dict of test_run statuses of a single test
 
@@ -746,3 +818,34 @@ def get_test_counts_in_date_range(test_id, start_date=None, stop_date=None,
     count_dict['failure'] = fail_query.count()
     count_dict['skips'] = skip_query.count()
     return count_dict
+
+
+def add_test_run_attachments(attach_dict, test_run_id, session=None):
+    """Add attachments a specific test run.
+
+    This method will take a dictionary and store key blob pair attachments in
+    the DB associated with the specified test_run.
+
+    :param dict attachments_dict: a dictionary which will generate a separate
+                                  key blob pair row associated with the
+                                  test_run_id
+    :param str test_run_id: the uuid of the test_run to update. (value of the
+                            id column for the row to be updated)
+    :param session: optional session object if one isn't provided a new session
+                    will be acquired for the duration of this operation
+
+    :return list: The list of created attachment objects
+    :rtype: subunit2sql.models.Attachments
+    """
+
+    session = session or get_session()
+    attachments = []
+    for label, attach in attach_dict.items():
+        attachment = models.Attachments()
+        attachment.label = label
+        attachment.attachment = attach
+        attachment.test_run_id = test_run_id
+        with session.begin():
+            session.add(attachment)
+        attachments.append(attachment)
+    return attachments
